﻿using Insort.Presentation.ViewModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Media;

namespace WpfTouchIssueTest.Views
{
    public enum AlarmStateSeverity
    {
        Info,
        Warning,
        Error,
        Fatal
    }

    public class AlarmInfoViewModel : ViewModelBase
    {
        public AlarmInfoViewModel(AlarmStateSeverity severity, string message, string possibleCause, string correction)
        {
            MessageColor = Brushes.Gray;
            IsShowQuitErrorMessage = false;

            switch (severity)
            {
                case AlarmStateSeverity.Info:
                    ImagePath = "/Resources/IconsM/StatusInformation.png";
                    break;
                case AlarmStateSeverity.Warning:
                    ImagePath = "/Resources/IconsM/StatusWarning.png";
                    MessageColor = Brushes.Orange;
                    break;
                case AlarmStateSeverity.Error:
                    ImagePath = "/Resources/IconsM/StatusCriticalError.png";
                    MessageColor = Brushes.Red;
                    IsShowQuitErrorMessage = true;
                    break;
                case AlarmStateSeverity.Fatal:
                    ImagePath = "/Resources/IconsM/StatusFatalError.png";
                    MessageColor = Brushes.Red;
                    IsShowQuitErrorMessage = true;
                    break;
            }

            Message = message;
            PossibleCause = possibleCause;
            Correction = correction;
        }

        #region +++ Published Properties +++
        public string ImagePath { get; set; }
        public string Message { get; set; }
        public Brush MessageColor { get; set; }
        public string PossibleCause { get; set; }
        public string Correction { get; set; }
        public bool IsShowQuitErrorMessage { get; protected set; }
        #endregion +++ Published Properties +++
    }

    class AlarmInfoViewModelDesign : AlarmInfoViewModel
    {
        protected override bool IsDesignMode
        {
            get
            {
                return true;
            }
        }

        public AlarmInfoViewModelDesign() : base(AlarmStateSeverity.Error, "", "", "")
        {
            ImagePath = "/Resources/IconsM/StatusWarning.png";
            Message = "This is a Message";
            PossibleCause = "This are the possible cause:" + Environment.NewLine + "1. xxx";
            Correction = "This is the correction:" + Environment.NewLine + "1. AAAA";
        }
    }
}
