﻿using Insort.Presentation.ViewModels;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WpfTouchIssueTest.Views
{
    public enum SystemStateLogCategory
    {
        None,
        Engine,
        MachineControl
    }

    public class SystemStateLogItem
    {
        public SystemStateLogItem(DateTime timestamp, AlarmStateSeverity severity, int messageId, string message, SystemStateLogCategory category)
        {
            Timestamp = timestamp;
            Severity = severity;
            MessageId = messageId;
            Message = message;
            Category = category;

            switch (category)
            {
                case SystemStateLogCategory.None:
                    Group = "";
                    break;
                case SystemStateLogCategory.Engine:
                    Group = "AlarmState_Label_Engine";
                    break;
                case SystemStateLogCategory.MachineControl:
                    Group = "AlarmState_Label_MachineControl";
                    break;
                default:
                    Group = "Default_Label_NotAvailable";
                    break;
            }
        }

        public DateTime Timestamp { get; set; }
        public AlarmStateSeverity Severity { get; set; }
        public int MessageId { get; set; }
        public string Message { get; set; }
        public string Group { get; private set; }
        public SystemStateLogCategory Category { get; set; }
    }

    public class SystemStateLogInfoViewModel : ViewModelBase
    {
        public delegate void OverallSystemStateSeverityReceivedHandler(AlarmStateSeverity overallSeverity);

        public SystemStateLogInfoViewModel()
        {
            LogItems = new ObservableCollection<SystemStateLogItem>();

            if (!IsDesignMode)
            {
                InitLogItemsContent();
                //_model.LogItemReceived += OnLogItemReceived;
            }
        }

        public event OverallSystemStateSeverityReceivedHandler OverallSystemStateSeverityReceived;

        #region +++ Published Properties +++
        public ObservableCollection<SystemStateLogItem> LogItems { get; set; }
        #endregion +++ Published Properties +++

        private void OnLogItemReceived(List<SystemStateLogItem> items)
        {
            const int MESSAGEID_NoAlarms = 0;

            SyncronizeUI(
                delegate ()
                {
                    LogItems.Clear();

                    foreach (var item in items)
                    {
                        LogItems.Add(item);
                    }

                    if (LogItems.Count == 0)
                    {
                        LogItems.Add(new SystemStateLogItem(DateTime.Now, AlarmStateSeverity.Info, MESSAGEID_NoAlarms, "NoAlarms", SystemStateLogCategory.None));
                    }

                    AlarmStateSeverity severity = GetHighestSeverity(LogItems);

                    OverallSystemStateSeverityReceived?.Invoke(severity);
                });
        }

        private void InitLogItemsContent()
        {
            OnLogItemReceived(new List<SystemStateLogItem>());
        }

        private AlarmStateSeverity GetHighestSeverity(ObservableCollection<SystemStateLogItem> items)
        {
            AlarmStateSeverity result = AlarmStateSeverity.Info;

            foreach (var item in items)
            {
                result = (AlarmStateSeverity)Math.Max((int)result, (int)item.Severity);
            }

            return result;
        }
    }

    class SystemStateLogInfoViewModelDesign : SystemStateLogInfoViewModel
    {
        protected override bool IsDesignMode
        {
            get
            {
                return true;
            }
        }

        public SystemStateLogInfoViewModelDesign()
        {
            LogItems = new ObservableCollection<SystemStateLogItem>();

            LogItems.Add(new SystemStateLogItem(DateTime.Now, AlarmStateSeverity.Info, 0, "Info", SystemStateLogCategory.None));
            LogItems.Add(new SystemStateLogItem(DateTime.Now, AlarmStateSeverity.Warning, 0, "Warning", SystemStateLogCategory.Engine));
            LogItems.Add(new SystemStateLogItem(DateTime.Now, AlarmStateSeverity.Error, 0, "Error", SystemStateLogCategory.MachineControl));
            LogItems.Add(new SystemStateLogItem(DateTime.Now, AlarmStateSeverity.Fatal, 0, "Fatal", SystemStateLogCategory.MachineControl));
        }
    }
}
